<?php
// Enable full error reporting and fatal catcher
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

register_shutdown_function(function () {
    $error = error_get_last();
    if ($error && in_array($error['type'], [E_ERROR, E_PARSE, E_CORE_ERROR, E_COMPILE_ERROR])) {
        echo "<pre style='color: red;'>FATAL ERROR: " . $error['message'] . " in " . $error['file'] . " on line " . $error['line'] . "</pre>";
    }
});

require_once 'auth.php';
requireLogin();
require_once '../config/db.php';

$user = currentUser();
$uploadBasePath = realpath(__DIR__ . '/../uploads');
$baseUrl = '/uploads';

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['delete_path'])) {
    $deletePath = realpath($_POST['delete_path']);
    if ($deletePath && strpos($deletePath, $uploadBasePath) === 0 && is_file($deletePath)) {
        $folderName = str_replace($uploadBasePath . '/', '', dirname($deletePath));
        $fileName = basename($deletePath);
        unlink($deletePath);

        $logStmt = $db->prepare("INSERT INTO audit_logs (user_id, action_type, target_type, target_name, notes) VALUES (?, 'delete', 'template_file', ?, ?)");
        $note = "Image deleted from {$folderName}";
        $logStmt->bind_param("iss", $user['id'], $fileName, $note);
        $logStmt->execute();
        $logStmt->close();

        header('Content-Type: application/json');
        echo json_encode(['status' => 'deleted']);
        exit;
    }
}

if (isset($_GET['ajax_gallery'])) {
    echo renderGallery($uploadBasePath, $baseUrl);
    exit;
}

function listImagesByFolder($dir, $baseUrl) {
    $folders = [];
    $rii = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($dir));
    foreach ($rii as $file) {
        if ($file->isDir()) continue;
        $ext = strtolower(pathinfo($file->getFilename(), PATHINFO_EXTENSION));
        if (!in_array($ext, ['jpg', 'jpeg', 'png', 'gif', 'webp'])) continue;

        $relativePath = str_replace($dir, '', $file->getPathname());
        $url = $baseUrl . str_replace(DIRECTORY_SEPARATOR, '/', $relativePath);
        $parts = explode('/', trim(dirname($relativePath), '/'));

        if (count($parts) >= 2) {
            $topLevel = $parts[0];
            $subFolder = $parts[1];
            $folders[$topLevel][$subFolder][] = [
                'path' => $file->getPathname(),
                'url'  => $url,
                'name' => $file->getFilename()
            ];
        } elseif (count($parts) === 1) {
            $topLevel = $parts[0];
            $folders[$topLevel]['_root'][] = [
                'path' => $file->getPathname(),
                'url'  => $url,
                'name' => $file->getFilename()
            ];
        }
    }
    ksort($folders);
    return $folders;
}

function renderGallery($dir, $baseUrl) {
    $grouped = listImagesByFolder($dir, $baseUrl);
    $output = '<div class="dashboard-wrapper">';
    $output .= '<h2 class="section-title">Uploaded Image Gallery</h2>';

    $output .= '<div style="display: flex; flex-wrap: wrap; gap: 15px; margin-bottom: 30px;">';
    foreach ($grouped as $top => $subs) {
        $topId = md5($top);
        $output .= '<div onclick="toggleFolder(\'' . $topId . '\')" style="cursor:pointer; text-align:center; width:100px;">';
        $output .= '<img src="folder.png" alt="Folder" style="width:48px; height:48px;"><br>';
        $output .= '<div style="font-size: 14px; margin-top: 5px;">' . htmlspecialchars($top) . '</div>';
        $output .= '</div>';
    }
    $output .= '</div>';

    foreach ($grouped as $top => $subs) {
        $topId = md5($top);
        $output .= '<div id="folder-' . $topId . '" class="folder-content" style="display:none; margin-bottom: 40px;">';
        $output .= '<h3 style="display: flex; align-items: center; gap: 10px;"><img src="folder.png" alt="Folder" style="width:20px; height:20px;"> ' . htmlspecialchars($top) . '</h3>';

        foreach ($subs as $sub => $images) {
            $output .= '<h4 style="margin: 10px 0 5px 0; font-weight: normal; color: #444;">' . htmlspecialchars($sub) . '</h4>';
            $output .= '<table style="width:100%; border-collapse: collapse; margin-bottom: 15px;">
                <thead>
                  <tr style="background:#eee; text-align:left;">
                    <th style="padding: 8px; border:1px solid #ccc;">Preview</th>
                    <th style="padding: 8px; border:1px solid #ccc;">Filename</th>
                    <th style="padding: 8px; border:1px solid #ccc;">Action</th>
                  </tr>
                </thead>
                <tbody>';
            foreach ($images as $img) {
                $output .= '<tr>';
                $output .= '<td style="padding: 8px; border:1px solid #ccc;"><img src="' . htmlspecialchars($img['url']) . '" style="max-height: 60px;"></td>';
                $output .= '<td style="padding: 8px; border:1px solid #ccc; word-break: break-all;"><a href="' . htmlspecialchars($img['url']) . '" target="_blank">' . htmlspecialchars($img['name']) . '</a></td>';
                $output .= '<td style="padding: 8px; border:1px solid #ccc;">
                    <form method="POST" class="delete-form" data-path="' . htmlspecialchars($img['path']) . '">
                        <button type="submit" style="background: #9b1c1c; color: white; border: none; padding: 6px 10px; border-radius: 4px; cursor: pointer;">Delete</button>
                    </form>
                </td>';
                $output .= '</tr>';
            }
            $output .= '</tbody></table>';
        }
        $output .= '</div>';
    }

    $output .= '</div>';
    return $output;
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title>Image Upload</title>
  <link rel="stylesheet" href="css/admin.css">
</head>
<body>
<div class="dashboard-wrapper">
  <h2>Upload Images</h2>
  <form id="upload-form">
    <label>Upload Folder (relative to /uploads/):</label><br>
    <input type="text" name="subfolder" id="subfolder" value="general" required><br><br>

    <label>Select or Drop Images Below:</label><br>
    <input type="file" name="images[]" id="images" multiple accept="image/*" required><br><br>

    <div id="drop-area" style="border:2px dashed #aaa; padding:20px; background:#f9f9f9; text-align:center;">
      <p>Drag and drop images here</p>
    </div>

    <div id="preview" style="display:flex; gap:10px; flex-wrap: wrap; margin-top:15px;"></div><br>

    <button type="submit">Upload</button>
  </form>

  <div id="results" style="margin-top:20px;"></div>
</div>

<div id="gallery-area">
  <?= renderGallery($uploadBasePath, $baseUrl) ?>
</div>

<script>
const form = document.getElementById('upload-form');
const preview = document.getElementById('preview');
const results = document.getElementById('results');
const input = document.getElementById('images');
const dropArea = document.getElementById('drop-area');
const gallery = document.querySelector('#gallery-area');

function previewFiles(files) {
  preview.innerHTML = '';
  Array.from(files).forEach(file => {
    if (!file.type.startsWith('image/')) return;
    const reader = new FileReader();
    reader.onload = function(e) {
      const img = document.createElement('img');
      img.src = e.target.result;
      img.style.maxHeight = '100px';
      img.style.margin = '5px';
      preview.appendChild(img);
    };
    reader.readAsDataURL(file);
  });
}

input.addEventListener('change', () => previewFiles(input.files));
dropArea.addEventListener('dragover', e => { e.preventDefault(); dropArea.style.background = '#eef'; });
dropArea.addEventListener('dragleave', () => { dropArea.style.background = '#f9f9f9'; });
dropArea.addEventListener('drop', e => {
  e.preventDefault();
  dropArea.style.background = '#f9f9f9';
  const files = e.dataTransfer.files;
  input.files = files;
  previewFiles(files);
});

form.addEventListener('submit', function(e) {
  e.preventDefault();
  const formData = new FormData();
  formData.append('subfolder', document.getElementById('subfolder').value);
  for (let file of input.files) {
    formData.append('images[]', file);
  }

  fetch('/upload_handler.php', {
    method: 'POST',
    body: formData
  })
  .then(res => res.json())
  .then(data => {
    results.innerHTML = '';
    if (data.success.length) {
      results.innerHTML += '<h3 style="color:green;">Uploaded:</h3><ul>' +
        data.success.map(url => `
          <li>
            <a href="${url}" target="_blank">${url.split('/').pop()}</a><br>
            <img src="${url}" alt="Uploaded Image" style="max-height:100px; margin-top:5px;">
          </li>
        `).join('') + '</ul>';
    }

    if (data.errors.length) {
      results.innerHTML += '<h3 style="color:red;">Errors:</h3><ul>' +
        data.errors.map(e => '<li>' + e + '</li>').join('') + '</ul>';
    }

    preview.innerHTML = '';
    input.value = '';

    setTimeout(() => {
      reloadGallery();
    }, 2000);
  })
  .catch(err => {
    results.innerHTML = '<p style="color:red;">Upload failed.</p>';
    console.error(err);
  });
});

function reloadGallery() {
  fetch('?ajax_gallery=1')
    .then(res => res.text())
    .then(html => {
      gallery.innerHTML = html;
      bindDeleteButtons();
    });
}

function bindDeleteButtons() {
  document.querySelectorAll('.delete-form').forEach(form => {
    form.addEventListener('submit', function(e) {
      e.preventDefault();
      if (!confirm('Delete this image?')) return;
      const formData = new FormData();
      formData.append('delete_path', form.getAttribute('data-path'));
      fetch('', { method: 'POST', body: formData })
        .then(res => res.json())
        .then(() => reloadGallery());
    });
  });
}

function toggleFolder(id) {
  document.querySelectorAll('.folder-content').forEach(el => el.style.display = 'none');
  const target = document.getElementById('folder-' + id);
  if (target) target.style.display = 'block';
}

bindDeleteButtons();
</script>
</body>
</html>
