<?php
/**
 * results_compiler_edit.php
 *
 * Compile and publish/unpublish match results, and manage segments.
 * Preserves the original Win/Loss input, Publish/Unpublish logic, and adds
 * a “Manage Matches & Segments” section at the bottom. In that section:
 *   - We pull `match_name` from `event_matches`.
 *   - If `reserved_segment_id` is non-NULL, we join to `reserved_segments`
 *     to get `submitter_id` → `users.username` for the “Lead Writer(s)” column.
 *   - Rows whose `status = 'submitted'` show a gray “Submitted” badge,
 *     and if it's a segment, an “Edit” link to `submit_reserved_segment.php`.
 */

ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

require_once '../config/db.php';
require_once 'auth.php';
requireLogin();

// ----------------------------------------------------------------
// 1) Fetch booking + event info
// ----------------------------------------------------------------
$bookingId = isset($_GET['booking_id']) ? (int)$_GET['booking_id'] : 0;
$userId    = $_SESSION['user_id'] ?? 0;
$groupId   = $_SESSION['group_id'] ?? 1;
$isAdmin   = ($groupId >= 9);

if (!$bookingId) {
    echo "<p>No booking selected.</p>";
    exit;
}

$stmt = $db->prepare(
    "SELECT 
        eb.id,
        eb.event_type,
        eb.event_id,
        eb.label,
        eb.air_date,
        eb.promo_deadline,
        eb.booking_status,
        e.name AS event_name
    FROM event_bookings eb
    JOIN events e ON eb.event_id = e.id
    WHERE eb.id = ?"
);
$stmt->bind_param('i', $bookingId);
$stmt->execute();
$booking = $stmt->get_result()->fetch_assoc();
$stmt->close();

$prevStatus = $booking['booking_status'] ?? '';

if (!$booking) {
    echo "<p>Booking not found.</p>";
    exit;
}

// ----------------------------------------------------------------
// 2) Handle POST: Save Draft, Publish, or Un-Publish
// ----------------------------------------------------------------
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $saveResults   = isset($_POST['save_results']);
    $publishToggle = isset($_POST['publish_toggle']);
    $unpubToggle   = isset($_POST['unpublish_toggle']);
    $wl_results    = $_POST['wl_results'] ?? '';

    // 2a) Save Draft only (reload)
    if ($saveResults && !$publishToggle && !$unpubToggle) {
        header("Location: results_compiler_edit.php?booking_id={$bookingId}");
        exit;
    }

    // Decode Win/Loss JSON
    $wl_array = [];
    if (!empty($wl_results)) {
        $decoded = json_decode($wl_results, true);
        if (is_array($decoded)) {
            $wl_array = $decoded;
        }
    }

    // --------------------
    // 2b) Publish: apply WL logic
    // --------------------
    if ($publishToggle) {
        // Fallback: load every competitor, then grab their result if it exists
        if (empty($wl_array)) {
            $wl_array = [];
            $fb = $db->prepare(
                "SELECT mc.match_id,
                        mc.character_id,
                        mr.result
                   FROM match_characters mc
                   JOIN event_matches m ON mc.match_id = m.id
                   LEFT JOIN match_results mr
                     ON mc.match_id     = mr.match_id
                    AND mc.character_id = mr.character_id
                  WHERE m.booking_id = ?"
            );
            $fb->bind_param('i', $bookingId);
            $fb->execute();
            $rs = $fb->get_result();
            while ($row = $rs->fetch_assoc()) {
                $key = $row['match_id'] . '_' . $row['character_id'];
                $wl_array[$key] = $row['result'] ?? '';
            }
            $fb->close();
        }

        // Update win/loss records
        foreach ($wl_array as $key => $val) {
            list($mId, $cId) = explode('_', $key);
            $matchId     = (int)$mId;
            $charId      = (int)$cId;
            $resultValue = $val;

            if (!$charId) continue;

            // Fetch existing WL record
            $chkStmt = $db->prepare(
                "SELECT id, auto_wins, auto_losses, auto_ncs, auto_matches
                   FROM win_loss_records
                  WHERE character_id = ?"
            );
            $chkStmt->bind_param('i', $charId);
            $chkStmt->execute();
            $row = $chkStmt->get_result()->fetch_assoc();
            $chkStmt->close();

            if ($row) {
                // Increment matches regardless of result
                $new_matches = $row['auto_matches'] + 1;
                $new_wins    = $row['auto_wins'] + ($resultValue === 'win'  ? 1 : 0);
                $new_losses  = $row['auto_losses'] + ($resultValue === 'loss' ? 1 : 0);
                $new_ncs     = $row['auto_ncs'] + ($resultValue === 'nc'   ? 1 : 0);

                $upd = $db->prepare(
                    "UPDATE win_loss_records
                       SET auto_wins    = ?,
                           auto_losses  = ?,
                           auto_ncs     = ?,
                           auto_matches = ?
                     WHERE id = ?"
                );
                $upd->bind_param('iiiii',
                    $new_wins,
                    $new_losses,
                    $new_ncs,
                    $new_matches,
                    $row['id']
                );
                $upd->execute();
                $upd->close();
            } else {
                // Insert new WL record (1 match counted)
                $aw = ($resultValue === 'win')  ? 1 : 0;
                $al = ($resultValue === 'loss') ? 1 : 0;
                $an = ($resultValue === 'nc')   ? 1 : 0;
                $am = 1;

                $ins = $db->prepare(
                    "INSERT INTO win_loss_records
                      (character_id, auto_wins, auto_losses, auto_ncs, auto_matches)
                    VALUES (?, ?, ?, ?, ?)"
                );
                $ins->bind_param('iiiii',
                    $charId,
                    $aw,
                    $al,
                    $an,
                    $am
                );
                $ins->execute();
                $ins->close();
            }
        }

      // 1. Update booking_status → 'Public'
$updB = $db->prepare(
    "UPDATE event_bookings
     SET booking_status = 'Public'
     WHERE id = ?"
);
$updB->bind_param('i', $bookingId);
$updB->execute();
$updB->close();

// 1. Get event name for title_reigns
$stmt = $db->prepare("
    SELECT e.name, eb.air_date
    FROM event_bookings eb
    JOIN events e ON eb.event_id = e.id
    WHERE eb.id = ?
");
$stmt->bind_param('i', $bookingId);
$stmt->execute();
$stmt->bind_result($eventName, $airDate);
$stmt->fetch();
$stmt->close();

// 2. Get matches with a title
$titleMatchStmt = $db->prepare("
  SELECT id, match_name, title_id
    FROM event_matches
   WHERE booking_id = ?
     AND title_id IS NOT NULL
");
$titleMatchStmt->bind_param('i', $bookingId);
$titleMatchStmt->execute();
$titleRes = $titleMatchStmt->get_result();

while ($match = $titleRes->fetch_assoc()) {
    $matchId   = (int)$match['id'];
    $matchName = $match['match_name'];
    $titleId   = (int)$match['title_id'];

    // 3. Find winner
    $winStmt = $db->prepare("SELECT character_id FROM match_results WHERE match_id = ? AND result = 'win' LIMIT 1");
    $winStmt->bind_param('i', $matchId);
    $winStmt->execute();
    $winnerRow = $winStmt->get_result()->fetch_assoc();
    $championAfter = $winnerRow['character_id'] ?? null;
    $winStmt->close();

    if (!$championAfter) continue;

    // 4. Get previous champion
    $oldChampStmt = $db->prepare("SELECT current_champion_id FROM titles WHERE id = ?");
    $oldChampStmt->bind_param('i', $titleId);
    $oldChampStmt->execute();
    $championBefore = $oldChampStmt->get_result()->fetch_assoc()['current_champion_id'] ?? null;
    $oldChampStmt->close();

    // 5. Insert into title_reigns
    $insertReign = $db->prepare("
        INSERT INTO title_reigns
          (title_id, event_name, match_name, change_date, champion_before, champion_after, summary)
        VALUES (?, ?, ?, ?, ?, ?, ?)
    ");
    $summary = "Auto‐recorded when show went Public";
    $insertReign->bind_param('isssiis',
        $titleId, $eventName, $matchName, $airDate, $championBefore, $championAfter, $summary
    );
    $insertReign->execute();
    $insertReign->close();

    // 6. Update current champion
    $updateTitle = $db->prepare("UPDATE titles SET current_champion_id = ? WHERE id = ?");
    $updateTitle->bind_param('ii', $championAfter, $titleId);
    $updateTitle->execute();
    $updateTitle->close();
}
$titleMatchStmt->close();


// 2. Get event name and air date
$stmt = $db->prepare("
    SELECT e.name, eb.air_date
    FROM event_bookings eb
    JOIN events e ON eb.event_id = e.id
    WHERE eb.id = ?
");
$stmt->bind_param('i', $bookingId);
$stmt->execute();
$stmt->bind_result($eventName, $airDate);
$stmt->fetch();
$stmt->close();

// 3. Get Discord webhook URL from site_settings
$stmt = $db->prepare("SELECT setting_value FROM site_settings WHERE setting_key = 'discord_news_webhook_url'");
$stmt->execute();
$stmt->bind_result($webhookUrl);
$stmt->fetch();
$stmt->close();

// 4. Post to Discord if webhook URL is available
if (!empty($webhookUrl)) {
    require_once __DIR__ . '/../functions/custom_functions.php';
   

require_once __DIR__ . '/../admin/libs/site-settings-lib.php'; // for getSetting()

$formattedDate = date('M j, Y', strtotime($airDate));

// Pull domain from site_settings
$siteUrl = rtrim(getSetting('site_url'), '/'); // remove trailing slash if present

// Create event link
$eventLink = "{$siteUrl}/event/{$bookingId}";

// Format message
$formattedMessage = "📣 **Event Now Public:** [**{$eventName}**]({$eventLink}) — {$formattedDate}";

// Post to Discord
discord_notify($webhookUrl, $formattedMessage);


  
}

// 5. Redirect
header("Location: results_compiler_edit.php?booking_id={$bookingId}&just_published=1");
exit;


// Redirect
header("Location: results_compiler_edit.php?booking_id={$bookingId}&just_published=1");
exit;
   }
    // --------------------
    // 2c) Un-Publish: rollback WL logic
    // --------------------
    if ($unpubToggle) {
        // Fallback: load every competitor, then grab their result if it exists
        if (empty($wl_array)) {
            $wl_array = [];
            $fb = $db->prepare(
                "SELECT mc.match_id,
                        mc.character_id,
                        mr.result
                   FROM match_characters mc
                   JOIN event_matches m ON mc.match_id = m.id
                   LEFT JOIN match_results mr
                     ON mc.match_id     = mr.match_id
                    AND mc.character_id = mr.character_id
                  WHERE m.booking_id = ?"
            );
            $fb->bind_param('i', $bookingId);
            $fb->execute();
            $rs = $fb->get_result();
            while ($row = $rs->fetch_assoc()) {
                $key = $row['match_id'] . '_' . $row['character_id'];
                $wl_array[$key] = $row['result'] ?? '';
            }
            $fb->close();
        }

        // Roll back win/loss records
        foreach ($wl_array as $key => $val) {
            list($mId, $cId) = explode('_', $key);
            $charId      = (int)$cId;
            $resultValue = $val;

            if (!$charId) continue;

            $chkStmt = $db->prepare(
                "SELECT id, auto_wins, auto_losses, auto_ncs, auto_matches
                   FROM win_loss_records
                  WHERE character_id = ?"
            );
            $chkStmt->bind_param('i', $charId);
            $chkStmt->execute();
            $row = $chkStmt->get_result()->fetch_assoc();
            $chkStmt->close();

            if (!$row) continue;

            $new_matches = max(0, $row['auto_matches'] - 1);
            $new_wins    = $row['auto_wins']    - ($resultValue === 'win'  ? 1 : 0);
            $new_losses  = $row['auto_losses']  - ($resultValue === 'loss' ? 1 : 0);
            $new_ncs     = $row['auto_ncs']     - ($resultValue === 'nc'   ? 1 : 0);

            $upd = $db->prepare(
                "UPDATE win_loss_records
                   SET auto_wins    = ?,
                       auto_losses  = ?,
                       auto_ncs     = ?,
                       auto_matches = ?
                 WHERE id = ?"
            );
            $upd->bind_param('iiiii',
                $new_wins,
                $new_losses,
                $new_ncs,
                $new_matches,
                $row['id']
            );
            $upd->execute();
            $upd->close();
        }

        // Revert booking_status → 'Booking'
        $updB = $db->prepare(
            "UPDATE event_bookings
               SET booking_status = 'Booking'
             WHERE id = ?"
        );
        $updB->bind_param('i', $bookingId);
        $updB->execute();
        $updB->close();

        header("Location: results_compiler_edit.php?booking_id={$bookingId}&just_unpublished=1");
        exit;
    }
}
?>

<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <title>Compile Results: <?php echo htmlspecialchars($booking['event_name'] . ' — ' . $booking['label']); ?></title>
    <link rel="stylesheet" href="css/admin.css">
    <style>
        table { width: 100%; border-collapse: collapse; margin-bottom: 20px; }
        th, td { padding: 8px; border: 1px solid #ccc; }
        th { background: #eee; }
        .btn { margin-right: 10px; padding: 6px 12px; cursor: pointer; border: none; border-radius: 3px; }
        .btn-publish   { background: #28a745; color: white; }
        .btn-unpublish { background: #ffc107; color: #212529; }
        .btn-save      { background: #007bff; color: white; }
        .badge { display: inline-block; padding: 4px 8px; font-size: 0.8rem; border-radius: 3px; color: #fff; }
        .badge-secondary { background-color: #6c757d; }
        .badge-secondary:hover { background-color: #5a6268; }
    </style>
</head>
<body>
<div class="dashboard-wrapper">
    <h2>Compile Results: <?php echo htmlspecialchars($booking['event_name'] . ' — ' . $booking['label']); ?></h2>

    <p>
        <strong>Air Date:</strong> <?php echo htmlspecialchars($booking['air_date']); ?><br>
        <strong>Promo Deadline:</strong> <?php echo htmlspecialchars($booking['promo_deadline']); ?><br>
        <strong>Status:</strong> <em><?php echo htmlspecialchars($booking['booking_status']); ?></em>
    </p>

    <form method="POST">
        <fieldset>
            <legend><b>SHOW COMPILER</b></legend>
            <i>Double check match results prior to setting to Public to ensure proper Win/Loss records.</i>
            <details style="margin-bottom: 20px;" closed>
                <summary style="cursor:pointer; font-weight:bold; font-size: 1.1em;">
                    Click to toggle Win/Loss Input Table
                </summary>
                <table>
                    <thead>
                        <tr>
                            <th style="width:5%">Match ID</th>
                            <th style="width:50%">Match Name</th>
                            <th style="width:20%">Competitor</th>
                            <th style="width:25%; text-align:center;">Result</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php
                        $ms = $db->prepare(
                            "SELECT id, match_name
                              FROM event_matches
                             WHERE booking_id = ?
                               AND is_segment = 0
                             ORDER BY sort_order ASC"
                        );
                        $ms->bind_param('i', $bookingId);
                        $ms->execute();
                        $matchesResult = $ms->get_result();

                        while ($m = $matchesResult->fetch_assoc()):
                            $cs = $db->prepare(
                                "SELECT mc.character_id, c.name
                                  FROM match_characters mc
                                  JOIN characters c ON mc.character_id = c.id
                                 WHERE mc.match_id = ?
                                 ORDER BY c.name ASC"
                            );
                            $cs->bind_param('i', $m['id']);
                            $cs->execute();
                            $comps = $cs->get_result()->fetch_all(MYSQLI_ASSOC);
                            $cs->close();

                            foreach ($comps as $comp):
                                $prev = '';
                                $rs = $db->prepare(
                                    "SELECT result 
                                      FROM match_results 
                                     WHERE match_id = ? 
                                       AND character_id = ?"
                                );
                                $rs->bind_param('ii', $m['id'], $comp['character_id']);
                                $rs->execute();
                                $row = $rs->get_result()->fetch_assoc();
                                $prev = $row['result'] ?? '';
                                $rs->close();
                        ?>
                        <tr>
                            <td><?php echo intval($m['id']); ?></td>
                            <td><?php echo htmlspecialchars($m['match_name']); ?></td>
                            <td><?php echo htmlspecialchars($comp['name']); ?></td>
                            <td style="text-align:center;">
                                <label>
                                    <input
                                        type="radio"
                                        name="wl_<?php echo "{$m['id']}_{$comp['character_id']}";?>"
                                        value="win"
                                        <?php if ($prev === 'win') echo 'checked'; ?>>
                                    W
                                </label>
                                &nbsp;
                                <label>
                                    <input
                                        type="radio"
                                        name="wl_<?php echo "{$m['id']}_{$comp['character_id']}";?>"
                                        value="loss"
                                        <?php if ($prev === 'loss') echo 'checked'; ?>>
                                    L
                                </label>
                                &nbsp;
                                <label>
                                    <input
                                        type="radio"
                                        name="wl_<?php echo "{$m['id']}_{$comp['character_id']}";?>"
                                        value="nc"
                                        <?php if ($prev === 'nc') echo 'checked'; ?>>
                                    NC
                                </label>
                            </td>
                        </tr>
                        <?php endforeach; endwhile; $ms->close(); ?>
                    </tbody>
                </table>
            </details>

            <div style="margin-top: 20px;">
                <a href="booking_manager.php" class="btn" style="margin-right: 10px;">← Go to Booking Manager</a>
                <button type="submit" name="save_results" class="btn btn-save">Save Draft Results</button>
                <?php if ($booking['booking_status'] !== 'Public'): ?>
                    <button type="submit" name="publish_toggle" class="btn btn-publish" style="margin-left: 10px;">Publish Results (Make Public)</button>
                <?php else: ?>
                    <button type="submit" name="unpublish_toggle" class="btn btn-unpublish" style="margin-left: 10px;">Return to Booking Status</button>
                <?php endif; ?>
            </div>

        </fieldset>
        <input type="hidden" name="wl_results" id="wl_results">
    </form>
</div>

<script>
// Collect radios JSON
document.querySelector('form').addEventListener('submit', function(e) {
    var allSel = {};
    document.querySelectorAll('input[type=radio]:checked').forEach(function(r) {
        var parts = r.name.split('_');
        if (parts.length===3) allSel[parts[1]+'_'+parts[2]] = r.value;
    });
    document.getElementById('wl_results').value = JSON.stringify(allSel);
});
</script>

<hr>

<div class="dashboard-wrapper" style="margin-top: 40px;">
    <h2>Manage Matches & Segments</h2>
    <table>
        <thead><tr><th>Match / Segment</th><th>Lead Writer(s)</th><th>Submit</th></tr></thead>
        <tbody>
            <?php
            $allStmt = $db->prepare(
                "SELECT em.id,em.match_name,em.status,em.reserved_segment_id,rs.submitter_id,u.username
                  FROM event_matches em
             LEFT JOIN reserved_segments rs ON em.reserved_segment_id=rs.id
             LEFT JOIN users u ON rs.submitter_id=u.id
                 WHERE em.booking_id=? ORDER BY em.id ASC"
            );
            $allStmt->bind_param('i',$bookingId);
            $allStmt->execute();
            $allRes=$allStmt->get_result();
            $allStmt->close();
            if($allRes->num_rows===0){
                echo "<tr><td colspan='3' class='empty'>No matches or segments found.</td></tr>";
            } else {
                while($r=$allRes->fetch_assoc()){
                    $mid=(int)$r['id'];
                    $name=htmlspecialchars($r['match_name']);
                    $status=strtolower($r['status']??'');
                    $writer=htmlspecialchars($r['username']??'');
                    $seg=$r['reserved_segment_id'];
                    echo '<tr><td>'.($seg?"(Segment) $name":$name)."</td><td>$writer</td><td>";
                    if($status==='submitted'){
                        echo "<span class='badge badge-secondary'>Submitted</span>";
                        if($seg) echo " <a class='btn btn-sm' href='submit_reserved_segment.php?match_id=$mid'>Edit</a>";
                    } else {
                        $link=$seg?'submit_reserved_segment.php?match_id='.$mid:'submit_match.php?match_id='.$mid;
                        echo "<a class='btn btn-sm' href='$link'>Submit</a>";
                    }
                    echo '</td></tr>';
                }
            }
            $segStmt=$db->prepare(
                "SELECT em.id,em.match_name,em.status
                   FROM event_matches em
                  WHERE em.booking_id=?
                    AND em.reserved_segment_id IS NOT NULL
                    AND LOWER(em.status)='submitted'
                ORDER BY em.id ASC"
            );
            $segStmt->bind_param('i',$bookingId);
            $segStmt->execute();
            $segRes=$segStmt->get_result();
            $segStmt->close();
            if($segRes->num_rows>0){
                echo "<tr><td colspan='3'><hr></td></tr>";
                echo "<tr><td colspan='3' style='font-style:italic;color:#555;'>Previously Submitted Segments:</td></tr>";
                while($s=$segRes->fetch_assoc()){
                    $id=(int)$s['id'];
                    $t=htmlspecialchars($s['match_name']);
                    $st=strtoupper(htmlspecialchars($s['status']));
                    echo "<tr><td>(Segment) $t</td><td></td><td>";
                    echo "<span class='badge badge-secondary'>$st</span> ";
                    echo "<a class='btn btn-sm' href='submit_reserved_segment.php?match_id=$id'>Edit</a>";
                    echo "</td></tr>";
                }
            }
            ?>
        </tbody>
    </table>
</div>

</body>
</html>
